div.row {
    margin-right: 0px;
    margin-left: 0px;
}

h2 {
    font-size: 2em;
    margin: 15px 0 15px 0;
}

h2 {
    padding: 15px;
}

h4 {
    font-weight: bold;
    font-size: 1.3em;
}

h3 {
    font-size: 1.5em;
    font-weight: bold;
}

.col-md-4, .col-md-8{
    transition: all 200ms; //replace 200ms with time of your choice
}
